@@ -138,6 +138,15 @@ class Say(object):
         Make a say object with the given options.
         """
         self.options = Say.options.push(kwargs)
+        
+    @staticmethod
+    def escape(s):
+        """
+        Double { and } characters in a string to 'escape' them so ``str.format``
+        doesn't treat them as template characters. NB This is NOT idempotent!
+        Escaping more than once (when { or } are present ) = ERROR.
+        """
+        return s.replace('{', '{{').replace('}', '}}') 
     
     def hr(self, sep=six.u('\u2500'), width=40, vsep=0, **kwargs):
         """
